@@ -209,7 +209,7 @@ __DATA__
   },
   /* --------------------------------------------------------------------------------------------------------------------------------- */
   { L0_TERMINAL_BRACKETED_NAME_STRING, MARPAESLIF_TERMINAL_TYPE_REGEX, 0, NULL,
-    "[\\s\\w]+", NULL, NULL,
+    "[\\s\\w\\[\\]]+", NULL, NULL,
     NULL, NULL
   },
   /* --------------------------------------------------------------------------------------------------------------------------------- */
